
uniform sampler2D tex;
uniform vec4 poly_color;
uniform vec4 tint_color;
uniform vec4 fade_color;
uniform float lighting;
uniform float fog_density;
uniform float fade_start;
uniform float fade_end;

float fog(const float dist, const float density, const float globaldensity) {
    const float LOG2 = -1.442695;
    float d = density * dist;
    return 1.0 - clamp(exp2(d * sqrt(d) * globaldensity * LOG2), 0.0, 1.0);
}


void main(void) {
	vec4 texel = texture2D(tex, gl_TexCoord[0].st);
	float fog_distance = gl_FragCoord.z / gl_FragCoord.w;
	float fog_attenuation = floor(fog(fog_distance, 0.0001 * ((256.0 - lighting) / 24.0), 0.30) * 10.0) / 10.0; // 0.30 is the default fog density
	vec4 fog_color = vec4(fade_color[0], fade_color[1], fade_color[2], 1.0);
	vec4 mixed_color = (tint_color.a > 0.0) ? texel * tint_color : texel * poly_color;
	vec4 fog_mix = mix(mixed_color, fog_color, fog_attenuation);
	vec4 final_color = mix(fog_mix, fog_color, ((256.0 - lighting) / 256.0));
	final_color[3] = mixed_color[3];
	final_color.a = poly_color.a * texel.a;
	gl_FragColor = final_color;
}
